/* -*-c-*-
 *
 * $Id: name.h,v 1.7 2003/10/12 00:14:55 mdw Exp $
 *
 * Looking up of names in symbol tables
 *
 * (c) 1998 EBI
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of `become'
 *
 * `Become' is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * `Become' is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with `become'; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*----- Revision history --------------------------------------------------*
 *
 * $Log: name.h,v $
 * Revision 1.7  2003/10/12 00:14:55  mdw
 * Major overhaul.  Now uses DSA signatures rather than the bogus symmetric
 * encrypt-and-hope thing.  Integrated with mLib and Catacomb.
 *
 * Revision 1.6  1998/04/23 13:24:21  mdw
 * Fix multiple inclusion guard macro name.
 *
 * Revision 1.5  1998/01/12 16:46:15  mdw
 * Fix copyright date.
 *
 * Revision 1.4  1997/09/17  10:26:11  mdw
 * Use rewritten class handler.  Support `none' class.
 *
 * Revision 1.3  1997/08/20  16:18:05  mdw
 * Replace `name_reinit' by `name_end' for more sensible restart.
 *
 * Revision 1.2  1997/08/04 10:24:24  mdw
 * Sources placed under CVS control.
 *
 * Revision 1.1  1997/07/21  13:47:46  mdw
 * Initial revision
 *
 */

#ifndef NAME_H
#define NAME_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Required headers --------------------------------------------------*/

#include <mLib/sym.h>

#ifndef CLASS_H
#  include "class.h"
#endif

/*----- Data structures ---------------------------------------------------*/

typedef struct name {
  sym_base base;			/* Base block for symbol table */
  class_node *c;				/* Base class pointer */
} name;

/*----- Functions provided ------------------------------------------------*/

/* --- @name_init@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Initialises the name table.  Requires the user database to
 *		be populated (see @userdb_local@ and @userdb_yp@).
 */

extern void name_init(void);

/* --- @name_end@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Closes down the name database, so that it can be
 *		reinitialised.
 */

extern void name_end(void);

/* --- @name_find@ --- *
 *
 * Arguments:	@const char *p@ = pointer to name to look up
 *		@unsigned create@ = whether to create the item
 *		@unsigned *f@ = whether the item was created
 *
 * Returns:	Pointer to a @name@ block containing the symbol, or
 *		zero if it wasn't found and we didn't want to create a
 *		new one.
 *
 * Use:		Looks up a name in the symbol table and returns the
 *		item so located.
 */

extern name *name_find(const char */*p*/,
		       unsigned /*create*/,
		       unsigned */*f*/);

/* --- @name_dump@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Dumps a complete listing of the symbol table.
 */

extern void name_dump(void);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
