/* -*-c-*-
 *
 * $Id: rule.h,v 1.6 1998/04/23 13:27:31 mdw Exp $
 *
 * Managing rule sets
 *
 * (c) 1998 EBI
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of `become'
 *
 * `Become' is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * `Become' is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with `become'; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*----- Revision history --------------------------------------------------*
 *
 * $Log: rule.h,v $
 * Revision 1.6  1998/04/23 13:27:31  mdw
 * Export structure of the rule list, for `bcquery's benefit.
 *
 * Revision 1.5  1998/01/12 16:46:26  mdw
 * Fix copyright date.
 *
 * Revision 1.4  1997/09/17  10:27:17  mdw
 * Use rewritten class handler.
 *
 * Revision 1.3  1997/08/20  16:22:49  mdw
 * Rename `rule_reinit' to `rule_end' for more sensible restart.
 *
 * Revision 1.2  1997/08/04 10:24:25  mdw
 * Sources placed under CVS control.
 *
 * Revision 1.1  1997/07/21  13:47:45  mdw
 * Initial revision
 *
 */

#ifndef RULE_H
#define RULE_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Required headers --------------------------------------------------*/

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#ifndef BECOME_H
#  include "become.h"
#endif

#ifndef CLASS_H
#  include "class.h"
#endif

/*----- Type definitions --------------------------------------------------*/

/* --- Rule block --- */

typedef struct rule {
  struct rule *next;			/* Next rule in the list */
  class_node *host;			/* Hosts this rule applies to */
  class_node *from;			/* From users in this class */
  class_node *to;			/* To users in this class */
  class_node *cmd;			/* To run commands in this class */
} rule;

/*----- Functions provided ------------------------------------------------*/

/* --- @rule_init@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Intialises the rule database.
 */

extern void rule_init(void);

/* --- @rule_end@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Empties the rule database.
 */

extern void rule_end(void);

/* --- @rule_list@ --- *
 *
 * Arguments:	---
 *
 * Returns:	The list of rules.
 *
 * Use:		Returns the address of the first node in the rule list.
 */

extern rule *rule_list(void);

/* --- @rule_add@ --- *
 *
 * Arguments:	@class_node *host@ = class of hosts this rule applies to
 *		@class_node *from@ = class of users allowed to change
 *		@class_node *to@ = class of users allowed to be changed to
 *		@class_node *cmd@ = class of commands allowed
 *
 * Returns:	---
 *
 * Use:		Registers another rule.
 */

extern void rule_add(class_node */*host*/, class_node */*from*/,
		     class_node */*to*/, class_node */*cmd*/);

/* --- @rule_check@ --- *
 *
 * Arguments:	@request *r@ = pointer to a request block
 *
 * Returns:	Zero if disallowed, nonzero if allowed.
 *
 * Use:		Checks a request to see if it's allowed.
 */

extern int rule_check(request */*r*/);

/* --- @rule_dump@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Dumps a map of the current ruleset to the trace output.
 */

extern void rule_dump(void);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
